@@ -13,7 +13,7 @@ package Device::I2C::ADV7611;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -75,6 +75,14 @@ sub readRegister {
     return $io->readByteData($register);
 }
 
+sub readRegister16 {
+    my ( $io, $addr, $register ) = @_;
+    $io->selectDevice($addr);
+    my $res = $io->readByteData($register);
+    $res <<= 8;
+    return $res + $io->readByteData( $register + 1 );
+}
+
 sub writeIO {
     my ( $io, $register, $value ) = @_;
     $io->writeRegister( CTRL_IO, $register, $value );
@@ -85,6 +93,11 @@ sub readIO {
     $io->readRegister( CTRL_IO, $register );
 }
 
+sub readIO16 {
+    my ( $io, $register ) = @_;
+    $io->readRegister16( CTRL_IO, $register );
+}
+
 sub writeHDMI {
     my ( $io, $register, $value ) = @_;
     $io->writeRegister( CTRL_HDMI, $register, $value );
@@ -95,6 +108,11 @@ sub readHDMI {
     $io->readRegister( CTRL_HDMI, $register );
 }
 
+sub readHDMI16 {
+    my ( $io, $register ) = @_;
+    $io->readRegister16( CTRL_HDMI, $register );
+}
+
 sub writeDPLL {
     my ( $io, $register, $value ) = @_;
     $io->writeRegister( CTRL_DPLL, $register, $value );
@@ -155,6 +173,11 @@ sub readCP {
     $io->readRegister( CTRL_CP, $register );
 }
 
+sub readCP16 {
+    my ( $io, $register ) = @_;
+    $io->readRegister16( CTRL_CP, $register );
+}
+
 sub initAddressMaps {
     my ($io) = @_;
 
@@ -211,8 +234,8 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611.svg?branch=build/master" alt="Travis status" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.06"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.06" alt="CPAN Testers result" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.06"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.06" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.07"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.07" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.07"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.07" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -220,7 +243,7 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
